read method
Reads a value from secure storage by its key.
Parameters:
key: The key of the value to retrieve.options: A map of platform-specific options for the read operation.
Returns:
- A Future that resolves to the value associated with the key, or
nullif the key does not exist.
Implementation
@override
Future<String?> read({
required String key,
required Map<String, String> options,
}) async => data[key];